# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Imports.ImportsEnums

Module implementing some enums for the import order checker.

### Global Attributes

None

### Classes

GroupEnum | Class representing the various import groups.
NodeTypeEnum | Class representing the import node types.

### Functions

None

## GroupEnum

Class representing the various import groups.

### Derived from

enum.IntEnum

### Class Attributes

FIRSTPARTY
FUTURE
LOCALPATH
STDLIB
THIRDPARTY

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## NodeTypeEnum

Class representing the import node types.

### Derived from

enum.IntEnum

### Class Attributes

IMPORT
IMPORT_FROM

### Class Methods

None

### Methods

None

### Static Methods

None

Up